{% load sitetree %}
<div class="pure-menu pure-menu-open pure-menu-box-vertical">
    <ul class="pure-menu-source-vertical">
        {% for item in sitetree_items %}
        <li class="{% if item.is_current or item.in_current_branch %}pure-menu-selected{% endif %}">
            <a href="{% sitetree_url for item %}">{{ item.title_resolved }}</a>
        </li>
        {% endfor %}
    </ul>
</div>